/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is Netscape Communications
 * Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 */

#ifndef nsUnicodeToGEOSTD8_h___
#define nsUnicodeToGEOSTD8_h___

#include "nsISupports.h"

/**
 * A character set converter from Unicode to GEOSTD8.
 *
 */
NS_METHOD
nsUnicodeToGEOSTD8Constructor(nsISupports *aOuter, REFNSIID aIID,
                              void **aResult);

#endif /* nsUnicodeToGEOSTD8_h___ */
